==> r-antd-0.2.4.tgz: package/es/r-table/export.js <==
import _defineProperty from "babel-runtime/helpers/defineProperty";
import _extends from "babel-runtime/helpers/extends";
import _slicedToArray from "babel-runtime/helpers/slicedToArray";
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
import * as React from "react";
import { Button, Modal, Radio, Checkbox } from "antd";
import RForm from "./../r-form";

var Export = function (_React$Component) {
    _inherits(Export, _React$Component);

    function Export() {
        _classCallCheck(this, Export);

        var _this = _possibleConstructorReturn(this, (Export.__proto__ || Object.getPrototypeOf(Export)).apply(this, arguments));

        _this.state = {
            visible: false,
            formFields: {
                columnsType: "ALL",
                checkedColumnKeys: [],
                rangeType: "ALL"
            }
        };
        _this.handleToggleVisible = function () {
            _this.setState(function (_ref) {
                var visible = _ref.visible;
                return { visible: !visible };
            });
        };
        _this.handleExportSubmit = function () {
            var _this$props = _this.props,
                columns = _this$props.columns,
                onExport = _this$props.onExport;
            var formFields = _this.state.formFields;
            var columnsType = formFields.columnsType,
                checkedColumnKeys = formFields.checkedColumnKeys,
                rangeType = formFields.rangeType;

            var nxtCheckedColumnKeys = columnsType === "ALL" ? columns.map(function (_ref2) {
                var key = _ref2.key,
                    dataIndex = _ref2.dataIndex;
                return key || dataIndex;
            }) : checkedColumnKeys;
            var exportResult = onExport(nxtCheckedColumnKeys, rangeType);
            if (!exportResult) {
                return;
            }
            _this.handleToggleVisible(); // close the dialog window.
        };
        _this.handleFormValuesChange = function (_ref3) {
            var _ref4 = _slicedToArray(_ref3, 2),
                formItemId = _ref4[0],
                formFieldValue = _ref4[1];

            _this.setState(function (_ref5) {
                var formFields = _ref5.formFields;
                return {
                    formFields: _extends({}, formFields, _defineProperty({}, formItemId, formFieldValue))
                };
            });
        };
        _this.handleOneClickExport = function () {
            _this.props.onExport();
        };
        return _this;
    }

    _createClass(Export, [{
        key: "render",
        value: function render() {
            var exportType = this.props.exportType;

            if (exportType === "by-one-click") {
                return React.createElement(
                    Button,
                    { onClick: this.handleOneClickExport },
                    "Export"
                );
            }
            var columns = this.props.columns;
            var _state = this.state,
                visible = _state.visible,
                formFields = _state.formFields;

            return React.createElement(
                "div",
                { style: { display: "inline-block" } },
                React.createElement(
                    Button,
                    { onClick: this.handleToggleVisible },
                    "Export"
                ),
                React.createElement(
                    Modal,
                    { title: "Export", footer: null, visible: visible, onCancel: this.handleToggleVisible },
                    React.createElement(RForm, { style: {
                            minWidth: 500,
                            maxWidth: "75%"
                        }, onValuesChange: this.handleFormValuesChange, footer: {
                            defaultActionSpan: 20,
                            defaultActionOffset: 4,
                            onSubmit: this.handleExportSubmit
                        }, formItems: [{
                            itemSpan: 24,
                            decorate: true,
                            decoratorOptions: {
                                initialValue: formFields.columnsType
                            },
                            id: "columnsType",
                            label: "Column(s)",
                            control: React.createElement(Radio.Group, { options: [{ label: "All", value: "ALL" }, { label: "Partial", value: "PARTIAL" }] })
                        }, {
                            visible: formFields.columnsType === "PARTIAL",
                            itemSpan: 24,
                            decorate: true,
                            id: "checkedColumnKeys",
                            label: " ",
                            colon: false,
                            control: React.createElement(Checkbox.Group, { options: columns.map(function (_ref6) {
                                    var title = _ref6.title,
                                        key = _ref6.key,
                                        dataIndex = _ref6.dataIndex;
                                    return {
                                        label: title,
                                        value: key || dataIndex
                                    };
                                }) })
                        }, {
                            itemSpan: 24,
                            decorate: true,
                            decoratorOptions: {
                                initialValue: formFields.rangeType
                            },
                            id: "rangeType",
                            label: "Range",
                            control: React.createElement(Radio.Group, { options: [{ label: "All rows", value: "ALL" }, { label: "Selected rows", value: "SELECTED" }] })
                        }] })
                )
            );
        }
    }]);

    return Export;
}(React.Component);

export default Export;

==> r-antd-0.2.5.tgz: package/es/r-table/export.js <==
import _defineProperty from "babel-runtime/helpers/defineProperty";
import _extends from "babel-runtime/helpers/extends";
import _slicedToArray from "babel-runtime/helpers/slicedToArray";
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
import * as React from "react";
import { Button, Modal, Radio, Checkbox } from "antd";
import RForm from "./../r-form";

var Export = function (_React$Component) {
    _inherits(Export, _React$Component);

    function Export() {
        _classCallCheck(this, Export);

        var _this = _possibleConstructorReturn(this, (Export.__proto__ || Object.getPrototypeOf(Export)).apply(this, arguments));

        _this.state = {
            visible: false,
            formFields: {
                columnsType: "ALL",
                checkedColumnKeys: [],
                rangeType: "ALL"
            }
        };
        _this.handleToggleVisible = function () {
            _this.setState(function (_ref) {
                var visible = _ref.visible;
                return { visible: !visible };
            });
        };
        _this.handleExportSubmit = function () {
            var _this$props = _this.props,
                columns = _this$props.columns,
                onExport = _this$props.onExport;
            var formFields = _this.state.formFields;
            var columnsType = formFields.columnsType,
                checkedColumnKeys = formFields.checkedColumnKeys,
                rangeType = formFields.rangeType;

            var nxtCheckedColumnKeys = columnsType === "ALL" ? columns.map(function (_ref2) {
                var key = _ref2.key,
                    dataIndex = _ref2.dataIndex;
                return key || dataIndex;
            }) : checkedColumnKeys;
            var exportResult = onExport(nxtCheckedColumnKeys, rangeType);
            if (!exportResult) {
                return;
            }
            _this.handleToggleVisible(); // close the dialog window.
        };
        _this.handleFormValuesChange = function (_ref3) {
            var _ref4 = _slicedToArray(_ref3, 2),
                formItemId = _ref4[0],
                formFieldValue = _ref4[1];

            _this.setState(function (_ref5) {
                var formFields = _ref5.formFields;
                return {
                    formFields: _extends({}, formFields, _defineProperty({}, formItemId, formFieldValue))
                };
            });
        };
        _this.handleOneClickExport = function () {
            _this.props.onExport();
        };
        return _this;
    }

    _createClass(Export, [{
        key: "render",
        value: function render() {
            var _props = this.props,
                locale = _props.locale,
                exportType = _props.exportType;

            if (exportType === "by-one-click") {
                return React.createElement(
                    Button,
                    { onClick: this.handleOneClickExport },
                    locale.exportBtnText
                );
            }
            var columns = this.props.columns;
            var _state = this.state,
                visible = _state.visible,
                formFields = _state.formFields;

            return React.createElement(
                "div",
                { style: { display: "inline-block" } },
                React.createElement(
                    Button,
                    { onClick: this.handleToggleVisible },
                    locale.exportBtnText
                ),
                React.createElement(
                    Modal,
                    { title: locale.exportBtnText, footer: null, visible: visible, onCancel: this.handleToggleVisible },
                    React.createElement(RForm, { style: {
                            minWidth: 500,
                            maxWidth: "75%"
                        }, onValuesChange: this.handleFormValuesChange, footer: {
                            defaultActionSpan: 20,
                            defaultActionOffset: 4,
                            submitText: locale.exportModal.submitText,
                            onSubmit: this.handleExportSubmit
                        }, formItems: [{
                            itemSpan: 24,
                            decorate: true,
                            decoratorOptions: {
                                initialValue: formFields.columnsType
                            },
                            id: "columnsType",
                            label: locale.columnsType.text,
                            control: React.createElement(Radio.Group, { options: [{ label: locale.columnsType.all, value: "ALL" }, { label: locale.columnsType.partial, value: "PARTIAL" }] })
                        }, {
                            visible: formFields.columnsType === "PARTIAL",
                            itemSpan: 24,
                            decorate: true,
                            id: "checkedColumnKeys",
                            label: " ",
                            colon: false,
                            control: React.createElement(Checkbox.Group, { options: columns.map(function (_ref6) {
                                    var title = _ref6.title,
                                        key = _ref6.key,
                                        dataIndex = _ref6.dataIndex;
                                    return {
                                        label: title,
                                        value: key || dataIndex
                                    };
                                }) })
                        }, {
                            itemSpan: 24,
                            decorate: true,
                            decoratorOptions: {
                                initialValue: formFields.rangeType
                            },
                            id: "rangeType",
                            label: locale.rangeType.text,
                            control: React.createElement(Radio.Group, { options: [{ label: locale.rangeType.all, value: "ALL" }, { label: locale.rangeType.selected, value: "SELECTED" }] })
                        }] })
                )
            );
        }
    }]);

    return Export;
}(React.Component);

export default Export;
